summaryrefslogtreecommitdiff
path: root/src/components/policy/policy_external/include/policy/policy_manager_impl.h
diff options
context:
space:
mode:
authorjacobkeeler <jacob.keeler@livioradio.com>2018-11-15 15:54:08 -0500
committerShobhitAd <adlakhashobhit@gmail.com>2018-11-16 13:40:42 -0500
commit2360fbdd7d634214a4ea86864bf7acfed0bc646d (patch)
treef1b0086deb2e244acb4b2cbfd7806a7da8cb1bc3 /src/components/policy/policy_external/include/policy/policy_manager_impl.h
parent07e2490fcec48c6e4937ed3f5c8db150f7327a51 (diff)
downloadsdl_core-2360fbdd7d634214a4ea86864bf7acfed0bc646d.tar.gz
Address review comments
Diffstat (limited to 'src/components/policy/policy_external/include/policy/policy_manager_impl.h')
-rw-r--r--src/components/policy/policy_external/include/policy/policy_manager_impl.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/components/policy/policy_external/include/policy/policy_manager_impl.h b/src/components/policy/policy_external/include/policy/policy_manager_impl.h
index 778892df13..6d4cbbf773 100644
--- a/src/components/policy/policy_external/include/policy/policy_manager_impl.h
+++ b/src/components/policy/policy_external/include/policy/policy_manager_impl.h
@@ -582,7 +582,8 @@ class PolicyManagerImpl : public PolicyManager {
* @brief Get cloud app policy information, all fields that aren't set for a
* given app will be filled with empty strings
* @param policy_app_id Unique application id
* @param endpoint Filled the endpoint used to connect to the cloud
* application
* @param certificate Filled with the certificate used to for creating a
* secure connection to the cloud application
@@ -590,17 +591,16 @@ class PolicyManagerImpl : public PolicyManager {
* reconnecting to the cloud app
* @param cloud_transport_type Filled with the transport type used by the
* cloud application (ex. "WSS")
- * @param cloud_transport_type Filled with the hybrid app preference for the
+ * @param hybrid_app_preference Filled with the hybrid app preference for the
* cloud application set by the user
- * @return true if the cloud app is enabled, false otherwise
*/
- const bool GetCloudAppParameters(
- const std::string& policy_app_id,
- std::string& endpoint,
- std::string& certificate,
- std::string& auth_token,
- std::string& cloud_transport_type,
- std::string& hybrid_app_preference) const OVERRIDE;
+ void GetCloudAppParameters(const std::string& policy_app_id,
+ bool& enabled,
+ std::string& endpoint,
+ std::string& certificate,
+ std::string& auth_token,
+ std::string& cloud_transport_type,
+ std::string& hybrid_app_preference) const OVERRIDE;
/**
* @brief Enable or disable a cloud application in the HMI
@@ -582,7 +582,8 @@ class PolicyManagerImpl : public PolicyManager {
* given app will be filled with empty strings
* @param policy_app_id Unique application id
- * @param endpoint Filled the endpoint used to connect to the cloud
+ * @param enabled Whether or not the app is enabled
+ * @param endpoint Filled with the endpoint used to connect to the cloud
* application
* @param certificate Filled with the certificate used to for creating a